@@ -3,7 +3,7 @@
 
 #ifndef PHIDGETS_INTERNAL
 #  error "this file is only supposed to be used from within libphidgets."
-#endif // PHIDGETS_INTERNAL
+#endif /* PHIDGETS_INTERNAL */
 
 #include <phidgets/phidgets.h>
 #include <debug.h>
@@ -12,12 +12,12 @@
   fprintf(phidgets_debug_stream, "*** ASSERTION FAILURE in %s() [%s:%d]: %s\n", \
       __FUNCTION__, __FILE__, __LINE__, #a)
 
-#endif // __INCLUDED_DEBUG_H__
+#endif /* __INCLUDED_DEBUG_H__ */
 
 /* COPYRIGHT --
  *
  * This file is part of libphidgets, a user-space library for phidgets.
- * libphidgets is (c) 2003-2004 Martin F. Krafft <krafft@ailab.ch>
+ * libphidgets is (c) 2003-2005 Martin F. Krafft <krafft@ailab.ch>
  * and distributed under the terms of the Artistic Licence.
  * See the ./COPYING file in the source tree root for more information.
  *
